@@ -1,8 +1,7 @@
 ### See ``http://www.mpi-forum.org/docs/mpi-20-html/node106.htm'' for details.
 
-### Initial MPI.
+### Initialize MPI.
 suppressMessages(library(pbdMPI, quietly = TRUE))
-init()
 .pbd_env$SPMD.CT$check.type <- FALSE
 if(comm.size() != 1){
   stop("Server too big.")
