@@ -11,7 +11,7 @@ SEXP spmd_allreduce_integer(SEXP R_send_data, SEXP R_recv_data,
 	    C_comm = INTEGER(R_comm)[0];
 	#if (MPI_LONG_DEBUG & 1) == 1
 		int C_comm_rank;
-		MPI_Comm_rank(comm[C_comm], &C_comm_rank);
+		MPI_Comm_rank(global_spmd_comm[C_comm], &C_comm_rank);
 	#endif
 
 	/* Loop through all. */
@@ -25,7 +25,7 @@ SEXP spmd_allreduce_integer(SEXP R_send_data, SEXP R_recv_data,
 
 		spmd_errhandler(MPI_Allreduce(C_send_data,
 			C_recv_data, SPMD_SHORT_LEN_MAX,
-			MPI_INT, SPMD_OP[C_op], comm[C_comm]));
+			MPI_INT, SPMD_OP[C_op], global_spmd_comm[C_comm]));
 		C_send_data = C_send_data + SPMD_SHORT_LEN_MAX;
 		C_recv_data = C_recv_data + SPMD_SHORT_LEN_MAX;
 		C_length_send_data = C_length_send_data - SPMD_SHORT_LEN_MAX;
@@ -42,12 +42,12 @@ SEXP spmd_allreduce_integer(SEXP R_send_data, SEXP R_recv_data,
 
 		spmd_errhandler(MPI_Allreduce(C_send_data,
 			C_recv_data, (int) C_length_send_data,
-			MPI_INT, SPMD_OP[C_op], comm[C_comm]));
+			MPI_INT, SPMD_OP[C_op], global_spmd_comm[C_comm]));
 	}
 #else
 	spmd_errhandler(MPI_Allreduce(INTEGER(R_send_data),
 		INTEGER(R_recv_data), LENGTH(R_send_data), MPI_INT,
-		SPMD_OP[INTEGER(R_op)[0]], comm[INTEGER(R_comm)[0]]));
+		SPMD_OP[INTEGER(R_op)[0]], global_spmd_comm[INTEGER(R_comm)[0]]));
 #endif
 	return(R_recv_data);
 } /* End of spmd_allreduce_integer(). */
@@ -62,7 +62,7 @@ SEXP spmd_allreduce_double(SEXP R_send_data, SEXP R_recv_data,
 	    C_comm = INTEGER(R_comm)[0];
 	#if (MPI_LONG_DEBUG & 1) == 1
 		int C_comm_rank;
-		MPI_Comm_rank(comm[C_comm], &C_comm_rank);
+		MPI_Comm_rank(global_spmd_comm[C_comm], &C_comm_rank);
 	#endif
 
 	/* Loop through all. */
@@ -76,7 +76,7 @@ SEXP spmd_allreduce_double(SEXP R_send_data, SEXP R_recv_data,
 
 		spmd_errhandler(MPI_Allreduce(C_send_data,
 			C_recv_data, SPMD_SHORT_LEN_MAX,
-			MPI_DOUBLE, SPMD_OP[C_op], comm[C_comm]));
+			MPI_DOUBLE, SPMD_OP[C_op], global_spmd_comm[C_comm]));
 		C_send_data = C_send_data + SPMD_SHORT_LEN_MAX;
 		C_recv_data = C_recv_data + SPMD_SHORT_LEN_MAX;
 		C_length_send_data = C_length_send_data - SPMD_SHORT_LEN_MAX;
@@ -93,12 +93,12 @@ SEXP spmd_allreduce_double(SEXP R_send_data, SEXP R_recv_data,
 
 		spmd_errhandler(MPI_Allreduce(C_send_data,
 			C_recv_data, (int) C_length_send_data,
-			MPI_DOUBLE, SPMD_OP[C_op], comm[C_comm]));
+			MPI_DOUBLE, SPMD_OP[C_op], global_spmd_comm[C_comm]));
 	}
 #else
 	spmd_errhandler(MPI_Allreduce(REAL(R_send_data), REAL(R_recv_data),
 		LENGTH(R_send_data), MPI_DOUBLE, SPMD_OP[INTEGER(R_op)[0]],
-		comm[INTEGER(R_comm)[0]]));
+		global_spmd_comm[INTEGER(R_comm)[0]]));
 #endif
 	return(R_recv_data);
 } /* End of spmd_allreduce_double(). */
@@ -113,7 +113,7 @@ SEXP spmd_allreduce_float(SEXP R_send_data, SEXP R_recv_data,
 	    C_comm = INTEGER(R_comm)[0];
 	#if (MPI_LONG_DEBUG & 1) == 1
 		int C_comm_rank;
-		MPI_Comm_rank(comm[C_comm], &C_comm_rank);
+		MPI_Comm_rank(global_spmd_comm[C_comm], &C_comm_rank);
 	#endif
 
 	/* Loop through all. */
@@ -127,7 +127,7 @@ SEXP spmd_allreduce_float(SEXP R_send_data, SEXP R_recv_data,
 
 		spmd_errhandler(MPI_Allreduce(C_send_data,
 			C_recv_data, SPMD_SHORT_LEN_MAX,
-			MPI_FLOAT, SPMD_OP[C_op], comm[C_comm]));
+			MPI_FLOAT, SPMD_OP[C_op], global_spmd_comm[C_comm]));
 		C_send_data = C_send_data + SPMD_SHORT_LEN_MAX;
 		C_recv_data = C_recv_data + SPMD_SHORT_LEN_MAX;
 		C_length_send_data = C_length_send_data - SPMD_SHORT_LEN_MAX;
@@ -144,12 +144,12 @@ SEXP spmd_allreduce_float(SEXP R_send_data, SEXP R_recv_data,
 
 		spmd_errhandler(MPI_Allreduce(C_send_data,
 			C_recv_data, (int) C_length_send_data,
-			MPI_FLOAT, SPMD_OP[C_op], comm[C_comm]));
+			MPI_FLOAT, SPMD_OP[C_op], global_spmd_comm[C_comm]));
 	}
 #else
 	spmd_errhandler(MPI_Allreduce(INTEGER(R_send_data),
 		INTEGER(R_recv_data), LENGTH(R_send_data), MPI_FLOAT,
-		SPMD_OP[INTEGER(R_op)[0]], comm[INTEGER(R_comm)[0]]));
+		SPMD_OP[INTEGER(R_op)[0]], global_spmd_comm[INTEGER(R_comm)[0]]));
 #endif
 	return(R_recv_data);
 } /* End of spmd_allreduce_float(). */
