@@ -12,7 +12,7 @@ SEXP spmd_reduce_integer(SEXP R_send_data, SEXP R_recv_data,
 	    C_comm = INTEGER(R_comm)[0];
 	#if (MPI_LONG_DEBUG & 1) == 1
 		int C_comm_rank;
-		MPI_Comm_rank(comm[C_comm], &C_comm_rank);
+		MPI_Comm_rank(global_spmd_comm[C_comm], &C_comm_rank);
 	#endif
 
 	/* Loop through all. */
@@ -26,7 +26,7 @@ SEXP spmd_reduce_integer(SEXP R_send_data, SEXP R_recv_data,
 
 		spmd_errhandler(MPI_Reduce(C_send_data, C_recv_data,
 			SPMD_SHORT_LEN_MAX, MPI_INT, SPMD_OP[C_op],
-			C_rank_dest, comm[C_comm]));
+			C_rank_dest, global_spmd_comm[C_comm]));
 		C_send_data = C_send_data + SPMD_SHORT_LEN_MAX;
 		C_recv_data = C_recv_data + SPMD_SHORT_LEN_MAX;
 		C_length_send_data = C_length_send_data - SPMD_SHORT_LEN_MAX;
@@ -43,12 +43,12 @@ SEXP spmd_reduce_integer(SEXP R_send_data, SEXP R_recv_data,
 
 		spmd_errhandler(MPI_Reduce(C_send_data, C_recv_data,
 			(int) C_length_send_data, MPI_INT, SPMD_OP[C_op],
-			C_rank_dest, comm[C_comm]));
+			C_rank_dest, global_spmd_comm[C_comm]));
 	}
 #else
 	spmd_errhandler(MPI_Reduce(INTEGER(R_send_data), INTEGER(R_recv_data),
 		LENGTH(R_send_data), MPI_INT, SPMD_OP[INTEGER(R_op)[0]],
-		INTEGER(R_rank_dest)[0], comm[INTEGER(R_comm)[0]]));
+		INTEGER(R_rank_dest)[0], global_spmd_comm[INTEGER(R_comm)[0]]));
 #endif
 	return(R_recv_data);
 } /* End of spmd_reduce_integer(). */
@@ -64,7 +64,7 @@ SEXP spmd_reduce_double(SEXP R_send_data, SEXP R_recv_data,
 	    C_comm = INTEGER(R_comm)[0];
 	#if (MPI_LONG_DEBUG & 1) == 1
 		int C_comm_rank;
-		MPI_Comm_rank(comm[C_comm], &C_comm_rank);
+		MPI_Comm_rank(global_spmd_comm[C_comm], &C_comm_rank);
 	#endif
 
 	/* Loop through all. */
@@ -78,7 +78,7 @@ SEXP spmd_reduce_double(SEXP R_send_data, SEXP R_recv_data,
 
 		spmd_errhandler(MPI_Reduce(C_send_data, C_recv_data,
 			SPMD_SHORT_LEN_MAX, MPI_DOUBLE, SPMD_OP[C_op],
-			C_rank_dest, comm[C_comm]));
+			C_rank_dest, global_spmd_comm[C_comm]));
 		C_send_data = C_send_data + SPMD_SHORT_LEN_MAX;
 		C_recv_data = C_recv_data + SPMD_SHORT_LEN_MAX;
 		C_length_send_data = C_length_send_data - SPMD_SHORT_LEN_MAX;
@@ -95,12 +95,12 @@ SEXP spmd_reduce_double(SEXP R_send_data, SEXP R_recv_data,
 
 		spmd_errhandler(MPI_Reduce(C_send_data, C_recv_data,
 			(int) C_length_send_data, MPI_DOUBLE, SPMD_OP[C_op],
-			C_rank_dest, comm[C_comm]));
+			C_rank_dest, global_spmd_comm[C_comm]));
 	}
 #else
 	spmd_errhandler(MPI_Reduce(REAL(R_send_data), REAL(R_recv_data),
 		LENGTH(R_send_data), MPI_DOUBLE, SPMD_OP[INTEGER(R_op)[0]],
-		INTEGER(R_rank_dest)[0], comm[INTEGER(R_comm)[0]]));
+		INTEGER(R_rank_dest)[0], global_spmd_comm[INTEGER(R_comm)[0]]));
 #endif
 	return(R_recv_data);
 } /* End of spmd_reduce_double(). */
@@ -116,7 +116,7 @@ SEXP spmd_reduce_float(SEXP R_send_data, SEXP R_recv_data,
 	    C_comm = INTEGER(R_comm)[0];
 	#if (MPI_LONG_DEBUG & 1) == 1
 		int C_comm_rank;
-		MPI_Comm_rank(comm[C_comm], &C_comm_rank);
+		MPI_Comm_rank(global_spmd_comm[C_comm], &C_comm_rank);
 	#endif
 
 	/* Loop through all. */
@@ -130,7 +130,7 @@ SEXP spmd_reduce_float(SEXP R_send_data, SEXP R_recv_data,
 
 		spmd_errhandler(MPI_Reduce(C_send_data, C_recv_data,
 			SPMD_SHORT_LEN_MAX, MPI_FLOAT, SPMD_OP[C_op],
-			C_rank_dest, comm[C_comm]));
+			C_rank_dest, global_spmd_comm[C_comm]));
 		C_send_data = C_send_data + SPMD_SHORT_LEN_MAX;
 		C_recv_data = C_recv_data + SPMD_SHORT_LEN_MAX;
 		C_length_send_data = C_length_send_data - SPMD_SHORT_LEN_MAX;
@@ -147,12 +147,12 @@ SEXP spmd_reduce_float(SEXP R_send_data, SEXP R_recv_data,
 
 		spmd_errhandler(MPI_Reduce(C_send_data, C_recv_data,
 			(int) C_length_send_data, MPI_FLOAT, SPMD_OP[C_op],
-			C_rank_dest, comm[C_comm]));
+			C_rank_dest, global_spmd_comm[C_comm]));
 	}
 #else
 	spmd_errhandler(MPI_Reduce(INTEGER(R_send_data), INTEGER(R_recv_data),
 		LENGTH(R_send_data), MPI_FLOAT, SPMD_OP[INTEGER(R_op)[0]],
-		INTEGER(R_rank_dest)[0], comm[INTEGER(R_comm)[0]]));
+		INTEGER(R_rank_dest)[0], global_spmd_comm[INTEGER(R_comm)[0]]));
 #endif
 	return(R_recv_data);
 } /* End of spmd_reduce_float(). */
